==> zio-aws-migrationhubrefactorspaces_2.12-5.17.224.4-sources.jar: zio/aws/migrationhubrefactorspaces/model/DeleteRouteRequest.scala <==
package zio.aws.migrationhubrefactorspaces.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.migrationhubrefactorspaces.model.primitives.{
  RouteId,
  EnvironmentId,
  ApplicationId
}
import scala.jdk.CollectionConverters._
final case class DeleteRouteRequest(
    applicationIdentifier: ApplicationId,
    environmentIdentifier: EnvironmentId,
    routeIdentifier: RouteId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest = {
    import DeleteRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest
      .builder()
      .applicationIdentifier(
        ApplicationId.unwrap(applicationIdentifier): java.lang.String
      )
      .environmentIdentifier(
        EnvironmentId.unwrap(environmentIdentifier): java.lang.String
      )
      .routeIdentifier(RouteId.unwrap(routeIdentifier): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest.ReadOnly =
    zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest
      .wrap(buildAwsValue())
}
object DeleteRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest =
      zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest(
        applicationIdentifier,
        environmentIdentifier,
        routeIdentifier
      )
    def applicationIdentifier: ApplicationId
    def environmentIdentifier: EnvironmentId
    def routeIdentifier: RouteId
    def getApplicationIdentifier: ZIO[Any, Nothing, ApplicationId] =
      ZIO.succeed(applicationIdentifier)
    def getEnvironmentIdentifier: ZIO[Any, Nothing, EnvironmentId] =
      ZIO.succeed(environmentIdentifier)
    def getRouteIdentifier: ZIO[Any, Nothing, RouteId] =
      ZIO.succeed(routeIdentifier)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest
  ) extends zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest.ReadOnly {
    override val applicationIdentifier: ApplicationId =
      zio.aws.migrationhubrefactorspaces.model.primitives
        .ApplicationId(impl.applicationIdentifier())
    override val environmentIdentifier: EnvironmentId =
      zio.aws.migrationhubrefactorspaces.model.primitives
        .EnvironmentId(impl.environmentIdentifier())
    override val routeIdentifier: RouteId =
      zio.aws.migrationhubrefactorspaces.model.primitives
        .RouteId(impl.routeIdentifier())
  }
  def wrap(
      impl: software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest
  ): zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-migrationhubrefactorspaces_3-5.17.129.2-sources.jar: zio/aws/migrationhubrefactorspaces/model/DeleteRouteRequest.scala <==
package zio.aws.migrationhubrefactorspaces.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.migrationhubrefactorspaces.model.primitives.{
  RouteId,
  EnvironmentId,
  ApplicationId
}
import scala.jdk.CollectionConverters.*
final case class DeleteRouteRequest(
    applicationIdentifier: ApplicationId,
    environmentIdentifier: EnvironmentId,
    routeIdentifier: RouteId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest = {
    import DeleteRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest
      .builder()
      .applicationIdentifier(
        ApplicationId.unwrap(applicationIdentifier): java.lang.String
      )
      .environmentIdentifier(
        EnvironmentId.unwrap(environmentIdentifier): java.lang.String
      )
      .routeIdentifier(RouteId.unwrap(routeIdentifier): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest.ReadOnly =
    zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest
      .wrap(buildAwsValue())
}
object DeleteRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest =
      zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest(
        applicationIdentifier,
        environmentIdentifier,
        routeIdentifier
      )
    def applicationIdentifier: ApplicationId
    def environmentIdentifier: EnvironmentId
    def routeIdentifier: RouteId
    def getApplicationIdentifier: ZIO[Any, Nothing, ApplicationId] =
      ZIO.succeed(applicationIdentifier)
    def getEnvironmentIdentifier: ZIO[Any, Nothing, EnvironmentId] =
      ZIO.succeed(environmentIdentifier)
    def getRouteIdentifier: ZIO[Any, Nothing, RouteId] =
      ZIO.succeed(routeIdentifier)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest
  ) extends zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest.ReadOnly {
    override val applicationIdentifier: ApplicationId =
      zio.aws.migrationhubrefactorspaces.model.primitives
        .ApplicationId(impl.applicationIdentifier())
    override val environmentIdentifier: EnvironmentId =
      zio.aws.migrationhubrefactorspaces.model.primitives
        .EnvironmentId(impl.environmentIdentifier())
    override val routeIdentifier: RouteId =
      zio.aws.migrationhubrefactorspaces.model.primitives
        .RouteId(impl.routeIdentifier())
  }
  def wrap(
      impl: software.amazon.awssdk.services.migrationhubrefactorspaces.model.DeleteRouteRequest
  ): zio.aws.migrationhubrefactorspaces.model.DeleteRouteRequest.ReadOnly =
    new Wrapper(impl)
}
